library(ape)

##### unrooted vs rooted tree #####

read.tree("desaturase_sub3.nwk") -> tree
plot(tree,"u",no.margin=T)

jpeg("desaturase_unrooted_tree.jpg",width=480,height=480,quality=100)
read.tree("desaturase_gamma.nwk") -> tree
plot(tree,"u",font = 1,no.margin=T)
add.scale.bar(0, 0.5)
dev.off()

jpeg("desaturase_rooted_tree.jpg",width=480,height=480,quality=100)
read.tree("desaturase_gamma.nwk") -> tree
root(tree,13,resolve.root = TRUE) -> tree_rooted
node.label <- rep(" ",21)
node.label[c(21,2)] <- paste0("D",1:2)
node.label[c(3,8,13)] <- paste0("S",1:3)
tree_rooted$node.label <- node.label
plot(tree_rooted,x.lim=c(0,1.4),show.node.label = TRUE, font = 1,
     no.margin=T)
add.scale.bar(0, 1)
dev.off()

##### The effect of assuming rate uniformity among site ######

### comparing distance matrices ###
read.csv("dist_homo.csv")->dist_homo
read.csv("dist_hetero_gamma.csv")->dist_gamma

as.matrix(dist_homo)->dist_homo
as.matrix(dist_gamma)->dist_gamma

jpeg("distance_homo_hetero.jpg",width=480,height=480,quality=100)
plot(dist_homo,dist_gamma,
     xlab="i (x̓TCgԂň)",ylab="i (x̓TCgԂŕϓ)",
     xlim=c(0,1.25),ylim=c(0,1.25))
abline(0,1,lty=2)
abline(h=0,v=0)
dev.off()

read.tree("desaturase_uniform.nwk") -> tree_unif
root(tree_unif,13,resolve.root = TRUE) -> tree_unif_rooted

##### comparing the rate- uniform vs geterogeneous trees #####

jpeg("desaturase_uniform_vs_gamma_rooted_tree.jpg",width=480,height=480,quality=100)
plot(tree_rooted,x.lim=c(0,1.4),y.lim=c(1,22),font=1,no.margin=T)
add.scale.bar(0, 1)
par(new=T)
xslide <- 0.12; yslide <- 0.3
plot(tree_unif_rooted,edge.lty=3,show.tip.label = FALSE, edge.width=1.5,
   x.lim=c(-xslide,1.4-xslide),y.lim=c(1-yslide,22-yslide),no.margin=T)
add.scale.bar(0, 2)
dev.off()

##### bootstrap
read.tree("desaturase_gamma_bootstrap.nwk") -> tree_boot
root(tree_boot,13,resolve.root = TRUE) -> tree_boot_rooted
node.label0 <- c("",paste0(" ",round(as.numeric(tree_boot_rooted$node.label[-c(1,21)])*100,0)),"")
tree_boot_rooted$node.label <- node.label0


jpeg("desaturase_boot_tree.jpg",width=480,height=480,quality=100)
plot(tree_boot_rooted,show.tip.label = T, show.node.label=T,font=1,
   x.lim=c(0,1.4),no.margin=T)
add.scale.bar(0, 1)
dev.off()

#### figure to explain parsimony
read.tree("desaturase_gamma.nwk") -> tree0
root(tree,13,resolve.root = TRUE) -> tree0_rooted0
tree0_rooted0$tip.label
tip.label0 <- paste0(tree0_rooted0$tip.label, ": ",rep("Ala",22))
tip.label0[c(5,6,21,22)] <- 
	paste0(tree0_rooted0$tip.label[c(5,6,21,22)], ": ","Var")
tree0_rooted0$tip.label <- tip.label0
node.label0 <- rep("",21)
node.label0[c(2:6,8:19)] <- " Ala"
tree0_rooted0$node.label <- node.label0
jpeg("desaturase_parsimony.jpg",width=480,height=480,quality=100)
plot(tree0_rooted0,show.tip.label = T, show.node.label=T,font=1,
   x.lim=c(0,1.4),no.margin=T)
text(0.5,6,"Ala->Var")
text(0.9,21,"Ala->Var")
dev.off()

